/*
 * Copyright (c) 2019, Felix Opatz
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#ifndef EVENT_H
#define EVENT_H

#include <stdint.h>

/**
 * Event that can be sent. Basically wraps a numeric event ID to be assigned by the user.
 * The last event ID is reserved for an invalid marker.
 */
class Event
{
public:
	enum
	{
		INVALID_EVENT_ID = 0xff
	};

	/**
	 * Constructor, defaulting to create an invalid event.
	 * @param eventId Event ID to assign.
	 */
	Event(uint8_t eventId = INVALID_EVENT_ID) : m_id(eventId)
	{
	}

	/**
	 * Getter for event ID.
	 * @result ID of event.
	 */
	uint8_t getId(void) const
	{
		return m_id;
	}

	/**
	 * Equality operator
	 * @param rhs Right hand side of comparison.
	 * @result True if instances are equal, false otherwise.
	 */
	bool operator ==(Event const& rhs) const
	{
		return m_id == rhs.m_id;
	}

	/**
	 * Inequality operator
	 * @param rhs Right hand side of comparison.
	 * @result True if instances are not equal, false otherwise.
	 */
	bool operator !=(Event const& rhs) const
	{
		return m_id != rhs.m_id;
	}

private:
	uint8_t m_id;
};

#endif
