/*
 * Copyright (c) 2019, Felix Opatz
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#ifndef GPIOPORT_H
#define GPIOPORT_H

#include <stdint.h>

#include "inputport.h"
#include "outputport.h"
#include "direction.h"

/**
 * Interface for 8 bit GPIO ports.
 * GPIO ports are expected to support the directions input and output. The interface also supports control of internal
 * pullup resistors as they are featured by AVR microcontrollers.
 */
class GpioPort : public InputPort, public OutputPort
{
public:
	/**
	 * Configure direction (input/output) for a set of individual pins.
	 * @param dir Direction to set.
	 * @param mask Mask with pins to apply setting to.
	 */
	virtual void setDirection(Direction dir, uint8_t mask = 0xff) = 0;

	/**
	 * Configure use of internal pullup resistors (if available) for a set of individual pins.
	 * @param state State of pullup resistors: bit set means active, bit cleared means inactive.
	 * @param mask Mask with pins to apply setting to.
	 */
	virtual void setPullup(uint8_t state, uint8_t mask = 0xff) = 0;
};

#endif
